@@ -10,7 +10,10 @@ fi
 # to change in the future.
 prefix=${prefix:=/usr}
 initdir=${initdir:=/etc/init.d}
-unitdir=${unitdir:=/usr/lib/systemd/system}
+unitdir_redhat=${unitdir:-/usr/lib/systemd/system}
+unitdir_debian=${unitdir:-/lib/systemd/system}
+defaultsdir_redhat=${defaultsdir:-/etc/sysconfig}
+defaultsdir_debian=${defaultsdir:-/etc/default}
 tmpfilesdir=${tmpfilesdir:=/usr/lib/tmpfiles.d}
 datadir=${datadir:=${prefix}/share}
 real_name=${real_name:=puppetdb}
@@ -27,6 +30,7 @@ symbindir=${symbindir:=/opt/puppetlabs/server/bin}
 app_prefix=${app_prefix:=/opt/puppetlabs/server/apps/${real_name}}
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
+system_config_dir=${system_config_dir:=${app_prefix}/config}
 
 
 ##################
@@ -64,15 +68,22 @@ function task_service {
     osdetection
 
     if [ "$OSFAMILY" = "RedHat" ]; then
-        defaultsdir="/etc/sysconfig"
+        unitdir=${unitdir_redhat}
+        defaultsdir=${defaultsdir_redhat}
         if [ $MAJREV -lt 7 ]; then
             task install_source_rpm_sysv
         else
             task install_source_rpm_systemd
         fi
     elif [ "$OSFAMILY" = "Debian" ]; then
-        defaultsdir="/etc/default"
-        task install_source_deb
+        unitdir=${unitdir_debian}
+        defaultsdir=${defaultsdir_debian}
+        sysv_codenames=("squeeze" "wheezy" "lucid" "precise" "trusty" "jessie")
+        if $(echo ${sysv_codenames[@]} | grep -q $CODENAME) ; then
+            task install_source_deb_sysv
+        else
+            task install_source_deb_systemd
+        fi
     else
         echo "Unsupported platform, exiting ..."
         exit 1
@@ -100,7 +111,7 @@ function task_install_source_rpm_systemd {
 }
 
 # Source based install for Debian based setups
-function task_install_source_deb {
+function task_install_source_deb_sysv {
     task preinst_deb
     task install_deb
     task sysv_init_deb
@@ -108,6 +119,15 @@ function task_install_source_deb {
     task postinst_deb
 }
 
+# Source based install for Debian based + systemd setups
+function task_install_source_deb_systemd {
+    task preinst_deb
+    task install_deb
+    task systemd_deb
+    task logrotate
+    task postinst_deb
+}
+
 # Install the ezbake package software. This step is used during RPM &
 # Debian packaging during the 'install' phases.
 function task_install {
@@ -117,6 +137,8 @@ function task_install {
     install -m 0755 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
     install -m 0644 ext/ezbake.manifest "${DESTDIR}${app_prefix}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
+
+
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
     install -m 0644 ext/config/bootstrap.cfg "${DESTDIR}${projconfdir}/bootstrap.cfg"
     install -m 0644 ext/config/conf.d/jetty.ini "${DESTDIR}${projconfdir}/conf.d/jetty.ini"
@@ -124,8 +146,10 @@ function task_install {
     install -m 0644 ext/config/conf.d/database.ini "${DESTDIR}${projconfdir}/conf.d/database.ini"
     install -m 0644 ext/config/conf.d/config.ini "${DESTDIR}${projconfdir}/conf.d/config.ini"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
+
     install -d -m 0755 "${DESTDIR}${app_prefix}/scripts"
     install -m 0755 install.sh "${DESTDIR}${app_prefix}/scripts"
+
     install -d -m 0755 "${DESTDIR}${app_prefix}/cli"
     install -d -m 0755 "${DESTDIR}${app_prefix}/cli/apps"
     install -d -m 0755 "${DESTDIR}${bindir}"
@@ -180,42 +204,56 @@ function task_termini {
     install -Dm 0644 puppet/functions/puppetdb_query.rb "${DESTDIR}${rubylibdir}/puppet/functions/puppetdb_query.rb"
 }
 
-function task_defaults {
-    install -d -m 0755 "${DESTDIR}${defaultsdir}"
-    install -m 0644 ext/default "${DESTDIR}${defaultsdir}/puppetdb"
+function task_defaults_redhat {
+    install -d -m 0755 "${DESTDIR}${defaultsdir_redhat}"
+    install -m 0644 ext/default "${DESTDIR}${defaultsdir_redhat}/puppetdb"
+}
+
+function task_defaults_deb {
+    install -d -m 0755 "${DESTDIR}${defaultsdir_debian}"
+    install -m 0644 ext/debian/puppetdb.default_file "${DESTDIR}${defaultsdir_debian}/puppetdb"
 }
 
 # Install the sysv and defaults configuration for Redhat.
 function task_sysv_init_redhat {
-    task defaults
+    task defaults_redhat
     install -d -m 0755 "${DESTDIR}${initdir}"
     install -m 0755 ext/redhat/init "${DESTDIR}${initdir}/puppetdb"
 }
 
 # Install the sysv and defaults configuration for SuSE.
 function task_sysv_init_suse {
-    task defaults
+    task defaults_redhat
     install -d -m 0755 "${DESTDIR}${initdir}"
     install -m 0755 ext/redhat/init.suse "${DESTDIR}${initdir}/puppetdb"
 }
 
 # Install the systemd and defaults configuration for Redhat.
 function task_systemd_redhat {
-    task defaults
-    install -d -m 0755 "${DESTDIR}${unitdir}"
-    install -m 0644 ext/redhat/puppetdb.service "${DESTDIR}${unitdir}/puppetdb.service"
+    task defaults_redhat
+    install -d -m 0755 "${DESTDIR}${unitdir_redhat}"
+    install -m 0644 ext/redhat/puppetdb.service "${DESTDIR}${unitdir_redhat}/puppetdb.service"
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetdb.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetdb.conf"
 }
 
 # Install the sysv and defaults configuration for Debian.
 function task_sysv_init_deb {
-    task defaults
+    task defaults_deb
     install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/debian/${real_name}.init "${DESTDIR}${initdir}/${real_name}"
+    install -m 0755 ext/debian/puppetdb.init_script "${DESTDIR}${initdir}/puppetdb"
     install -d -m 0755 "${DESTDIR}${rundir}"
 }
 
+# Install the systemd and defaults configuration for Debian.
+function task_systemd_deb {
+    task defaults_deb
+    install -d -m 0755 "${DESTDIR}${unitdir_debian}"
+    install -m 0644 ext/debian/puppetdb.service_file "${DESTDIR}${unitdir_debian}/puppetdb.service"
+    install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
+    install -m 0644 ext/puppetdb.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetdb.conf"
+}
+
 function task_service_account {
     # Add puppetdb group
     getent group puppetdb > /dev/null || \
@@ -301,11 +339,13 @@ function debug_echo {
 function osdetection {
     OSFAMILY=`facter osfamily`
     MAJREV=`facter operatingsystemmajrelease`
+    CODENAME=`facter os.distro.codename`
 
     debug_echo "OS Detection results"
     debug_echo
     debug_echo "OSFAMILY: ${OSFAMILY}"
     debug_echo "MAJREV: ${MAJREV}"
+    debug_echo "CODENAME: ${CODENAME}"
     debug_echo
 }
 
