@@ -6,9 +6,10 @@
    and the format expected by the rest of the application."
   (:import [java.security KeyStore]
            [org.joda.time Minutes Days Period])
-  (:require [clojure.tools.logging :as log]
+  (:require [puppetlabs.i18n.core :as i18n]
+            [clojure.tools.logging :as log]
             [puppetlabs.kitchensink.core :as kitchensink]
-            [puppetlabs.trapperkeeper.bootstrap :refer [find-bootstrap-config]]
+            [puppetlabs.trapperkeeper.bootstrap :as tk-bootstrap]
             [clj-time.core :as time]
             [clojure.java.io :as io]
             [me.raynes.fs :as fs]
@@ -146,6 +147,7 @@
      :store-usage s/Int
      :max-frame-size (pls/defaulted-maybe s/Int 209715200)
      :temp-usage s/Int
+     :memory-usage s/Int
      :max-command-size (pls/defaulted-maybe s/Int (default-max-command-size))
      :reject-large-commands (pls/defaulted-maybe String "false")}))
 
@@ -156,6 +158,7 @@
    :max-frame-size s/Int
    :max-command-size s/Int
    :reject-large-commands Boolean
+   (s/optional-key :memory-usage) s/Int
    (s/optional-key :store-usage) s/Int
    (s/optional-key :temp-usage) s/Int})
 
@@ -163,8 +166,7 @@
   "Schema for validating the incoming [puppetdb] block"
   (all-optional
     {:certificate-whitelist s/Str
-     ;; The `historical-catalogs-limit` setting is only used by `pe-puppetdb`
-     :historical-catalogs-limit (pls/defaulted-maybe s/Int 3)
+     :historical-catalogs-limit (pls/defaulted-maybe s/Int 0)
      :disable-update-checking (pls/defaulted-maybe String "false")}))
 
 (def puppetdb-config-out
@@ -258,7 +260,7 @@
   [config]
   (let [vardir (some-> (get-in config [:global :vardir])
                        io/file
-                       fs/absolute-path
+                       kitchensink/absolute-path
                        fs/file)]
     (cond
      (nil? vardir)
@@ -332,24 +334,44 @@
     (System/exit 1)) ; cf. PDB-2053
   config-data)
 
+(def default-web-router-config
+  {:puppetlabs.trapperkeeper.services.metrics.metrics-service/metrics-webservice
+   {:route "/metrics"
+    :server "default"}
+   :puppetlabs.trapperkeeper.services.status.status-service/status-service
+   {:route "/status"
+    :server "default"}
+   :puppetlabs.puppetdb.pdb-routing/pdb-routing-service
+   {:route "/pdb"
+    :server "default"}
+   :puppetlabs.puppetdb.dashboard/dashboard-redirect-service
+   {:route "/"
+    :server "default"}})
+
+(defn filter-out-non-tk-config [config-data]
+  (select-keys config-data
+               [:debug :bootstrap-config :config :plugins :help]))
+
 (defn add-web-routing-service-config
   [config-data]
-  (let [default-web-router-service {:puppetlabs.puppetdb.metrics/metrics-service "/metrics"
-                                    :puppetlabs.trapperkeeper.services.status.status-service/status-service "/status"
-                                    :puppetlabs.puppetdb.pdb-routing/pdb-routing-service "/pdb"}
-        bootstrap-cfg (-> (find-bootstrap-config config-data)
-                          slurp
-                          str/split-lines)
-        dashboard-redirect? (contains? (set bootstrap-cfg)
-                                       "puppetlabs.puppetdb.dashboard/dashboard-redirect-service")]
-    (doseq [[svc route] default-web-router-service]
+  (let [bootstrap-cfg (->> (tk-bootstrap/find-bootstrap-configs (filter-out-non-tk-config config-data))
+                           (mapcat tk-bootstrap/read-config)
+                           set)
+        ;; If a user didn't specify one of the services in their bootstrap.cfg
+        ;; we remove the web-router-config for that service
+        filtered-web-router-config (into {} (for [[svc route] default-web-router-config
+                                                  :when (contains? bootstrap-cfg (utils/kwd->str svc))]
+                                              [svc route]))]
+    (doseq [[svc route] filtered-web-router-config]
       (when (get-in config-data [:web-router-service svc])
-        (-> (format "Configuration of the `%s` route is not allowed. This setting defaults to `%s`." svc route)
-            utils/println-err)))
-    ;; We override the users settings as to make the above routes *not* configurable
-    (update config-data :web-router-service merge default-web-router-service
-            (when dashboard-redirect?
-              {:puppetlabs.puppetdb.dashboard/dashboard-redirect-service "/"}))))
+        (utils/println-err
+         (i18n/trs "Configuring the route for `{0}` is not allowed. The default route is `{1}` and server is `{2}`."
+                   svc (:route route) (:server route)))))
+    ;; We override the users settings as to make the above routes *not*
+    ;; configurable
+    (-> config-data
+        (assoc-in [:metrics :reporters :jmx :enabled] true)
+        (update :web-router-service merge filtered-web-router-config))))
 
 (defn- add-mq-defaults
   [config-data]
